//
//***********************************************************
//
//
// SIMPLE MAIL CHIMP WRAPPER FOR ADDING SUBSCRIBERS TO A LIST
//
// NOTES:
//
// - Uses version 3.0 of API (Latest at 22/08/2016)
// - Before using, create an API Key and  list via the MailChimp 
//   web admin and use ID values in the below constants.
// - Very far from being a complete API wrapper but allows for the simplest 
//   Form of sign up form within AS3 aps
// - Should be easy to add additional fields as outlined at the API documentation: 
//   http://developer.mailchimp.com/documentation/mailchimp/reference/lists/members/#create-post_lists_list_id_members
//
// USAGE:
//
// - Simplest usage example: MailChimp.addSubscriber("james@codeandvisual.com")
// - Include optional event handler functions for success/fail events, if required
//
//
//***********************************************************
			
package {
	import flash.display.Sprite;
	import flash.events.Event;
	import flash.events.EventDispatcher;
	import flash.events.IOErrorEvent;
	import flash.net.URLLoader;
	import flash.net.URLRequest;
	import flash.net.URLRequestHeader;
	
	/**
	 * ...
	 * @author Code and Visual
	 */
	public class MailChimp extends EventDispatcher {
		public static const KEY:String = "xxxxxxxxxxxxxxxxxxxxxx-xxx" // Put your API Kety in Here
		public static const LIST_ID:String = "xxxxxxxxxx" // Put your List ID in here
		public static const PROTOCOL:String = "https://"
		public static const VERSION:String = "3.0"
		public static const SERVICE_URL:String = PROTOCOL + dc + ".api.mailchimp.com/" + VERSION + "/"
		public static const ADD_SUBSCRIBER_URL:String = SERVICE_URL + "lists/" + LIST_ID + "/members"
		
		//
		public function MailChimp() {
			// (!) No need to instantiate.
		}
		
		//
		//***********************************************************
		//
		//
		// API
		//
		//
		//***********************************************************
		public static function addSubscriber(thisEmailAddress:String,thisSuccess:Function=null, thisError:Function=null):void {
			var myNewMemeberData:Object = {status: 'subscribed', email_address: thisEmailAddress}
			var myJSON:String = JSON.stringify(myNewMemeberData)
			var myHeaders:Array = [new URLRequestHeader("Authorization", "anykey " + KEY), new URLRequestHeader("content-type", "application/json")]
			postSubscriber(ADD_SUBSCRIBER_URL, myHeaders, myJSON, thisSuccess, thisError);
		}
		
		//
		//***********************************************************
		//
		//
		// NETWORK FUNCTIONS
		//
		//
		//***********************************************************
		private static function postSubscriber(thisPath:String, thisHeaders:Array, thisData:String, thisSuccess:Function, thisError:Function):void {
			var myLoader:URLLoader = new URLLoader();
			var myRequest:URLRequest = new URLRequest(thisPath);
			myRequest.method = "POST";
			myRequest.requestHeaders = thisHeaders
			myRequest.data = thisData;
			if(thisError){
				myLoader.addEventListener(IOErrorEvent.IO_ERROR, thisError);
			}
			if(thisSuccess){
				myLoader.addEventListener(Event.COMPLETE, thisSuccess);
			}
			//
			myLoader.load(myRequest);
		}
		
		
		//
		//***********************************************************
		//
		//
		// HELPER FUNCTIONS
		//
		//
		//***********************************************************
		// DC is the Data Centre (each API key will be assigned a data centre)
		public static function get dc():String {
			var mySplit:Array = KEY.split("-");
			return mySplit[mySplit.length - 1]
		}
	}
}